roundhouse\.contrib\.serializers\.msgpack module
================================================

.. automodule:: roundhouse.contrib.serializers.msgpack
    :members:
    :undoc-members:
    :show-inheritance:
